@@ -6,7 +6,7 @@
     'name_es_CO': 'Moneda',
     'name_es_ES': 'Divisa',
     'name_fr_FR': 'Devise',
-    'version': '1.6.0',
+    'version': '1.8.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -33,9 +33,11 @@ Permet de formater les montants en fonction de la devise.
         'currency.xml',
     ],
     'translation': [
+        'cs_CZ.csv',
         'de_DE.csv',
         'es_CO.csv',
         'es_ES.csv',
         'fr_FR.csv',
+        'ru_RU.csv',
     ]
 }
